@@ -21,7 +21,7 @@ use Moose::Util::TypeConstraints qw( role_type union enum );
 use namespace::autoclean;
 
 # ABSTRACT: Author Test::Version tests
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 sub gather_files {
   my($self) = @_;
@@ -49,7 +49,7 @@ sub munge_files
   my $use_finder = 0;
 
   if(@{ $self->finder } > 0) {
-    @filenames = map { Path::Class::File->new($_->name)->relative('.')->stringify }
+    @filenames = map { $_->name }
       grep { not ($_->can('is_bytes') and $_->is_bytes) }
       @{ $self->found_files };
     $use_finder = 1;
@@ -97,10 +97,11 @@ has is_strict => (
 );
 
 has _is_strict => (
-  is => 'ro',
-  isa => 'Bool',
-  lazy => 1,
-  default => sub {
+  is       => 'ro',
+  isa      => 'Bool',
+  lazy     => 1,
+  init_arg => undef,
+  default  => sub {
     my($self) = @_;
     $self->is_strict eq 'adaptive' ? ($self->zilla->is_trial ? 0 : 1) : $self->is_strict
   },
@@ -148,7 +149,7 @@ Dist::Zilla::Plugin::Test::Version - Author Test::Version tests
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
